@@ -7,26 +7,36 @@
 #' @template arg_learner
 #' @param dw.perc [\code{numeric(1)}]\cr
 #'   See \code{\link{downsample}}.
+#'   Default is 1.
 #' @param dw.stratify [\code{logical(1)}]\cr
 #'   See \code{\link{downsample}}.
+#'   Default is \code{FALSE}.
 #' @template ret_learner
 #' @family downsample
 #' @export
 makeDownsampleWrapper = function(learner, dw.perc = 1, dw.stratify = FALSE) {
   learner = checkLearner(learner)
-  assertNumber(dw.perc, na.ok = FALSE, lower = 0, upper = 1)
-  assertFlag(dw.stratify)
+  pv = list()
+  if (!missing(dw.perc)) {
+    assertNumber(dw.perc, na.ok = FALSE, lower = 0, upper = 1)
+    pv$dw.perc = dw.perc
+  }
+  if (!missing(dw.stratify)) {
+    assertFlag(dw.stratify)
+    pv$dw.stratify = dw.stratify
+  }
   id = paste(learner$id, "downsampled", sep = ".")
   ps = makeParamSet(
     makeNumericLearnerParam(id = "dw.perc", lower = 0, upper = 1, default = 1),
     makeLogicalLearnerParam(id = "dw.stratify", default = FALSE)
   )
-  pv = list(dw.perc = dw.perc, dw.stratify = dw.stratify)
   makeBaseWrapper(id, learner, package = "mlr", par.set = ps, par.vals = pv, cl = "DownsampleWrapper")
 }
 
 #' @export
-trainLearner.DownsampleWrapper = function(.learner, .task, .subset, .weights = NULL, dw.perc, dw.stratify, ...) {
+trainLearner.DownsampleWrapper = function(.learner, .task, .subset, .weights = NULL,
+  dw.perc = 1, dw.stratify = TRUE, ...) {
+
   .task = subsetTask(.task, .subset)
   .task = downsample(.task, perc = dw.perc, stratify = dw.stratify)
   m = train(.learner$next.learner, .task, weights = .weights)
