@@ -108,7 +108,7 @@ makeMeasure = function(id, minimize, properties = character(0L), allowed.pred.ty
 default.measures = function(x) {
   type = if (inherits(x, "TaskDesc"))
     x$type
-  else if (inherits(x, "SupervisedTask"))
+  else if (inherits(x, "Task"))
     x$task.desc$type
   else if (inherits(x, "Learner"))
     x$type
@@ -116,7 +116,8 @@ default.measures = function(x) {
     classif = list(mmce),
     regr = list(mse),
     costsens = list(mcp),
-    surv = list(cindex)
+    surv = list(cindex),
+    cluster = list(db)
   )
 }
 
