@@ -6,7 +6,7 @@ makeRLearner.regr.penalized.ridge = function() {
     par.set = makeParamSet(
       makeNumericLearnerParam(id = "lambda2", default = 0, lower = 0)
     ),
-    properties = c("missings", "numerics", "factors")
+    properties = c("numerics", "factors")
   )
 }
 
