@@ -3,8 +3,8 @@
 #'   Default is 100.
 #' @export
 #' @rdname TuneControl
-makeTuneControlRandom = function(same.resampling.instance = TRUE, impute.val = Inf, maxit = 100L) {
+makeTuneControlRandom = function(same.resampling.instance = TRUE, maxit = 100L) {
   maxit = asCount(maxit)
-  makeTuneControl(same.resampling.instance = same.resampling.instance, impute.val = impute.val,
+  makeTuneControl(same.resampling.instance = same.resampling.instance,
     maxit = maxit, start = NULL, cl = "TuneControlRandom")
 }
