@@ -7,7 +7,7 @@
 #'
 #' @param learners [(list of) \code{\link{Learner}}]\cr
 #'   Learning algorithms which should be compared.
-#' @param tasks [(list of) \code{\link{SupervisedTask}}]\cr
+#' @param tasks [(list of) \code{\link{Task}}]\cr
 #'   Tasks that learners should be run on.
 #' @param resamplings [(list of) \code{\link{ResampleDesc}} | \code{\link{ResampleInstance}}]\cr
 #'   Resampling strategy for each tasks.
@@ -30,9 +30,9 @@ benchmark = function(learners, tasks, resamplings, measures, show.info = getMlrO
   names(learners) = learner.ids
 
   # check tasks
-  tasks = ensureVector(tasks, 1L, "SupervisedTask")
+  tasks = ensureVector(tasks, 1L, "Task")
   assertList(tasks, min.len = 1L)
-  checkListElementClass(tasks, "SupervisedTask")
+  checkListElementClass(tasks, "Task")
   task.ids = extractSubList(tasks, c("task.desc", "id"))
   if (anyDuplicated(task.ids))
     stop("Tasks need unique ids!")
