@@ -3,8 +3,8 @@ checkLearner = function(learner, type = NULL, weights = FALSE, ...) {
     learner = makeLearner(learner)
   else
     assertClass(learner, classes = "Learner")
-  if (!is.null(type) && learner$type != type)
-    stopf("Learner '%s' must be of type %s, not: %s", learner$id, type, learner$type)
+  if (!is.null(type) && learner$type %nin% type)
+    stopf("Learner '%s' must be of type %s, not: %s", learner$id, collapse(type), learner$type)
   if (weights && !hasProperties(learner, "weights"))
     stopf("Learner '%s' must support weights, but does not!", learner$id)
   setHyperPars(learner, ...)
