@@ -3,8 +3,7 @@ checkMeasures = function(measures, obj, aggr = NULL) {
     measures = default.measures(obj)
   } else {
     measures = ensureVector(measures, n = 1L, cl = "Measure")
-    assertList(measures)
-    checkListElementClass(measures, "Measure")
+    assertList(measures, types = "Measure")
   }
   if (!is.null(aggr))
     measures = lapply(measures, setAggregation, aggr = aggr)
