@@ -5,44 +5,42 @@
 #'
 #' Code inspired by \code{\link[klaR]{errormatrix}}.
 #'
-#' @param pred [\code{\link{Prediction}}]\cr
-#'   Result of a prediction.
+#' @template arg_pred
 #' @param relative [\code{logical(1)}]\cr
-#' 	If \code{TRUE} rows are normalized to show relative frequencies.
-#'  Default is \code{FALSE}.
+#'   If \code{TRUE} rows are normalized to show relative frequencies.
+#'   Default is \code{FALSE}.
 #' @return [\code{matrix}]. A confusion matrix.
 #' @export
-#' @seealso \code{\link{predict}}
+#' @seealso \code{\link{predict.WrappedModel}}
 #' @examples
 #' ## create classification task and use linear discriminant analysis for classification
-#' task <- makeClassifTask(data = iris, target = "Species")
-#' lrn <- makeLearner("classif.lda")
+#' task = makeClassifTask(data = iris, target = "Species")
+#' lrn = makeLearner("classif.lda")
 #'
 #' ## set up training and test data
-#' n <- nrow(iris)
-#' mixed.set <- sample(1:n)
-#' training.set <- mixed.set[1:(n/2)]
-#' test.set <- mixed.set[(n/2 + 1):n]
+#' n = nrow(iris)
+#' mixed.set = sample(1:n)
+#' training.set = mixed.set[1:(n/2)]
+#' test.set = mixed.set[(n/2 + 1):n]
 #'
 #' ## train model
-#' mod <- train(lrn, task, subset = training.set)
+#' mod = train(lrn, task, subset = training.set)
 #'
 #' ## get predictions and show calculate confusion matrix
-#' pred <- predict(mod, newdata = iris[test.set, ])
+#' pred = predict(mod, newdata = iris[test.set, ])
 #' print(getConfMatrix(pred))
 #' print(getConfMatrix(pred, relative = TRUE))
-getConfMatrix = function(pred, relative=FALSE) {
-  checkArg(pred, "Prediction")
-  checkArg(relative, "logical", len=1L, na.ok=FALSE)
+getConfMatrix = function(pred, relative = FALSE) {
+  assertClass(pred, classes = "Prediction")
+  assertFlag(relative)
 
   if (pred$task.desc$type != "classif")
     stop("Can only calculate confusion matrix for classification predictions, not: %s",
       pred$task.desc$type)
-  truth = pred$data$truth
   resp = pred$data$response
   cls = pred$task.desc$class.levels
   n = length(cls)
-  tab = table(truth, resp)
+  tab = table(pred$data$truth, resp)
   mt = tab * (matrix(1, ncol = n, nrow = n) - diag(, n, n))
   rowsum = rowSums(mt)
   colsum = colSums(mt)
@@ -50,7 +48,7 @@ getConfMatrix = function(pred, relative=FALSE) {
   dimnames(result) = list(true = c(cls, "-SUM-"),
                           predicted = c(cls, "-SUM-"))
   if (relative) {
-    # FIXME this is quite inefficient
+    # FIXME: this is quite inefficient
     total = sum(result[1:n, 1:n])
     n1 = n + 1
     result[n1, 1:n] = if (result[n1, n1] != 0) result[n1, 1:n]/result[n1, n1] else 0
