@@ -9,7 +9,7 @@
 #'
 #' @param object [\code{\link{WrappedModel}}]\cr
 #'   Wrapped model, result of \code{\link{train}}.
-#' @param task [\code{\link{SupervisedTask}}]\cr
+#' @param task [\code{\link{Task}}]\cr
 #'   The task. If this is passed, data from this task is predicted.
 #' @param newdata [\code{data.frame}]\cr
 #'   New observations which should be predicted.
@@ -48,7 +48,7 @@ predict.WrappedModel = function(object, task, newdata, subset, ...) {
 
   # FIXME: cleanup if cases
   if (missing(newdata)) {
-    assertClass(task, classes = "SupervisedTask")
+    assertClass(task, classes = "Task")
     size = task$task.desc$size
   } else {
     assertDataFrame(newdata, min.rows = 1L)
@@ -80,7 +80,7 @@ predict.WrappedModel = function(object, task, newdata, subset, ...) {
   }
 
   # was there an error in building the model? --> return NAs
-  if(inherits(model, "FailureModel")) {
+  if (inherits(model, "FailureModel")) {
     p = predictFailureModel(model, newdata)
     time.predict = NA_real_
   } else {
@@ -92,35 +92,30 @@ predict.WrappedModel = function(object, task, newdata, subset, ...) {
     )
     pars = c(pars, getHyperPars(learner, "predict"))
     debug.seed = getMlrOption("debug.seed", NULL)
-    if(!is.null(debug.seed))
+    if (!is.null(debug.seed))
       set.seed(debug.seed)
-    if(inherits(getLearnerModel(model), "NoFeaturesModel")) {
-      p = predict_nofeatures(model, newdata)
-      time.predict = 0
-    } else {
-      opt.ole = getMlrOption("on.learner.error")
-      if (getMlrOption("show.learner.output"))
-        fun1 = identity
-      else
-        fun1 = capture.output
-      if (opt.ole == "stop")
-        fun2 = identity
-      else
-        fun2 = function(x) try(x, silent = TRUE)
-      old.warn.opt = getOption("warn")
-      on.exit(options(warn = old.warn.opt))
-      if (getMlrOption("on.learner.warning") == "quiet") {
-        options(warn = -1L)
-      }
-      st = system.time(fun1(p <- fun2(do.call(predictLearner2, pars))), gcFirst = FALSE)
-      time.predict = as.numeric(st[3L])
-      # was there an error during prediction?
-      if(is.error(p)) {
-        if (opt.ole == "warn")
-          warningf("Could not predict with learner %s: %s", learner$id, as.character(p))
-        p = predictFailureModel(model, newdata)
-        time.predict = NA_real_
-      }
+    opt.ole = getMlrOption("on.learner.error")
+    if (getMlrOption("show.learner.output"))
+      fun1 = identity
+    else
+      fun1 = capture.output
+    if (opt.ole == "stop")
+      fun2 = identity
+    else
+      fun2 = function(x) try(x, silent = TRUE)
+    old.warn.opt = getOption("warn")
+    on.exit(options(warn = old.warn.opt))
+    if (getMlrOption("on.learner.warning") == "quiet") {
+      options(warn = -1L)
+    }
+    st = system.time(fun1(p <- fun2(do.call(predictLearner2, pars))), gcFirst = FALSE)
+    time.predict = as.numeric(st[3L])
+    # was there an error during prediction?
+    if (is.error(p)) {
+      if (opt.ole == "warn")
+        warningf("Could not predict with learner %s: %s", learner$id, as.character(p))
+      p = predictFailureModel(model, newdata)
+      time.predict = NA_real_
     }
   }
   if (missing(task))
