@@ -9,12 +9,11 @@ tuneGenSA = function(learner, task, resampling, measures, par.set, control, opt.
     start = sampleValue(par.set, start, trafo = FALSE)
   start = convertStartToNumeric(start, par.set)
   ctrl.gensa = control$extra.args
+  cx = function(x) convertXNumeric(x, par.set)
   or = GenSA(par = start, fn = tunerFitnFun, lower = low, upper = upp, control = ctrl.gensa,
     learner = learner, task = task, resampling = resampling, measures = measures,
     par.set = par.set, ctrl = control, opt.path = opt.path, show.info = show.info,
-    trafo = TRUE, convertx = identity, remove.nas = FALSE)
-  i = getOptPathBestIndex(opt.path, measureAggrName(measures[[1]]), ties = "random")
-  e = getOptPathEl(opt.path, i)
-  makeTuneResult(learner, control, e$x, e$y, opt.path)
+    convertx = cx, remove.nas = FALSE)
+  makeTuneResultFromOptPath(learner, par.set, measures, control, opt.path)
 }
 
