@@ -1,18 +1,15 @@
 #FIXME: check whether optimization can be paralleized if req. by user
-# FIXME check trafo
-# FIXME: example missing
 
 #' @title Hyperparameter tuning.
 #'
 #' @description
 #' Optimizes the hyperparameters of a learner.
-#' Allows for different optimization methods, such as grid search, evolutionary strategies, etc.
-#' You can select such an algorithm (and its settings)
+#' Allows for different optimization methods, such as grid search, evolutionary strategies,
+#' iterated F-race, etc. You can select such an algorithm (and its settings)
 #' by passing a corresponding control object. For a complete list of implemented algorithms look at
 #' \code{\link{TuneControl}}.
 #'
-#' Note that if tranformations are associated with the parameters, the returned result will contain
-#' transformed values in the optimal result and the path.
+#' Multi-criteria tuning can be done with \code{\link{tuneParamsMultiCrit}}.
 #'
 #' @template arg_learner
 #' @template arg_task
@@ -20,7 +17,7 @@
 #'   Resampling strategy to evaluate points in hyperparameter space. If you pass a description,
 #'   it is instantiated once at the beginning by default, so all points are
 #'   evaluated on the same training/test sets.
-#'   If you want to change that behaviour, look at \code{\link{TuneControl}}.
+#'   If you want to change that behavior, look at \code{\link{TuneControl}}.
 #' @template arg_measures_opt
 #' @param par.set [\code{\link[ParamHelpers]{ParamSet}}]\cr
 #'   Collection of parameters and their constraints for optimization.
@@ -30,9 +27,41 @@
 #' @return [\code{\link{TuneResult}}].
 #' @family tune
 #' @export
+#' @examples
+#' # a grid search for an SVM (with a tiny number of points...)
+#' # note how easily we can optimize on a log-scale
+#' ps = makeParamSet(
+#'   makeNumericParam("C", lower = -12, upper = 12, trafo = function(x) 2^x),
+#'   makeNumericParam("sigma", lower = -12, upper = 12, trafo = function(x) 2^x)
+#' )
+#' ctrl = makeTuneControlGrid(resolution = 2L)
+#' rdesc = makeResampleDesc("CV", iters = 2L)
+#' res = tuneParams("classif.ksvm", iris.task, rdesc, par.set = ps, control = ctrl)
+#' print(res)
+#' print(as.data.frame(res$opt.path))
+#' print(as.data.frame(trafoOptPath(res$opt.path)))
+#'
+#' \dontrun{
+#' # we optimize the SVM over 3 kernels simultanously
+#' # note how we use dependent params (requires = ...) and iterated F-racing here
+#' ps = makeParamSet(
+#'   makeNumericParam("C", lower = -12, upper = 12, trafo = function(x) 2^x),
+#'   makeDiscreteParam("kernel", values = c("vanilladot", "polydot", "rbfdot")),
+#'   makeNumericParam("sigma", lower = -12, upper = 12, trafo = function(x) 2^x,
+#'     requires = quote(kernel == "rbfdot")),
+#'   makeIntegerParam("degree", lower = 2L, upper = 5L,
+#'     requires = quote(kernel == "polydot"))
+#' )
+#' print(ps)
+#' ctrl = makeTuneControlIrace(maxExperiments = 200L)
+#' rdesc = makeResampleDesc("Holdout")
+#' res = tuneParams("classif.ksvm", iris.task, rdesc, par.set = ps, control = ctrl)
+#' print(res)
+#' print(head(as.data.frame(res$opt.path)))
+#' }
 tuneParams = function(learner, task, resampling, measures, par.set, control, show.info = getMlrOption("show.info")) {
   learner = checkLearner(learner)
-  assertClass(task, classes = "SupervisedTask")
+  assertClass(task, classes = "Task")
   measures = checkMeasures(measures, learner)
   assertClass(par.set, classes = "ParamSet")
   assertClass(control, classes = "TuneControl")
@@ -41,7 +70,7 @@ tuneParams = function(learner, task, resampling, measures, par.set, control, sho
   if (inherits(resampling, "ResampleDesc") && control$same.resampling.instance)
     resampling = makeResampleInstance(resampling, task = task)
   assertFlag(show.info)
-  checkTunerParset(learner, par.set, control)
+  checkTunerParset(learner, par.set, measures, control)
   control = setDefaultImputeVal(control, measures)
 
   cl = getClass1(control)
