@@ -22,6 +22,13 @@ multiclass.test  = multiclass.df[multiclass.test.inds, ]
 multiclass.class.col = 5
 multiclass.task = makeClassifTask("multiclass", data = multiclass.df, target = multiclass.target)
 
+noclass.df = iris[,-5]
+noclass.train.inds = c(1:30, 51:80, 101:130)
+noclass.test.inds  = setdiff(1:150, noclass.train.inds)
+noclass.train = noclass.df[noclass.train.inds, ]
+noclass.test  = noclass.df[noclass.test.inds, ]
+noclass.task = makeClusterTask("noclass", data = noclass.df)
+
 data(BostonHousing)
 regr.df = BostonHousing
 regr.formula = medv ~ .
